from setuptools import setup
from setuptools import find_packages

setup(name='mgab-panda',
      version='0.9.1',
      description='The panda song',
      author='mgab',
      author_email='mgab@panda.com',
      packages=find_packages())
